==> agiledataecho-0.0.2.0020-sources.jar: replacer.sh <==
#!/bin/sh
sed -i "s#@profile_active@#$agiledataecho_profile_active#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@athena_logger_enable@#$agiledataecho_athena_logger_enable#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@lmc_endpoint@#$lmc_endpoint#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/logback-spring-private.xml

sed -i "s#@redis_host@#$agiledataecho_redis_host#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@redis_port@#$agiledataecho_redis_port#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@redis_password@#$agiledataecho_redis_password#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml

sed -i "s#@mongodb_database@#$agiledataecho_mongodb_echo_database#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@mongodb_echo_agileDataPagebase@#$agiledataecho_mongodb_echo_agileDataPagebase#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml


sed -i "s#@dbServer@#$agiledataecho_dbServer#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@dbName@#$agiledataecho_dbName#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@dbUser@#$agiledataecho_dbUser#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@dbPassword@#$agiledataecho_dbPassword#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml

sed -i "s#@rabbitmq_host@#$agiledataecho_rabbitmq_host#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@rabbitmq_port@#$agiledataecho_rabbitmq_port#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml

sed -i "s#@rabbitmq_username@#$agiledataecho_rabbitmq_username#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@rabbitmq_password@#$agiledataecho_rabbitmq_password#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@rabbitmq_virtual_host@#$agiledataecho_rabbitmq_virtual_host#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml

sed -i "s#@iam_uri@#$agiledataecho_iam_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@iam_bossUri@#$agiledataecho_iam_bossUri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@iam_cacUri@#$agiledataecho_iam_cacUri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@themeMap_uri@#$agiledataecho_themeMap_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@themeMap_rootUri@#$agiledataecho_themeMap_rootUri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@themeMap_dataMapUri@#$agiledataecho_themeMap_dataMapUri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@themeMap_knowledgeGraphUri@#$agiledataecho_themeMap_knowledgeGraphUri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@themeMap_supportPerson@#$agiledataecho_themeMap_supportPerson#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@bpm_uri@#$agiledataecho_bpm_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@uibot_uri@#$agiledataecho_uibot_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@eoc_uri@#$agiledataecho_eoc_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@im_uri@#$agiledataecho_im_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@taskEngine_uri@#$agiledataecho_taskEngine_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@ptm_uri@#$agiledataecho_ptm_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@abt_uri@#$agiledataecho_abt_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@aim_uri@#$agiledataecho_aim_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@aam_uri@#$agiledataecho_aam_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@ade_uri@#$agiledataecho_ade_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@adt_uri@#$agiledataecho_adt_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@semc_uri@#$agiledataecho_semc_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@chatBI_uri@#$agiledataecho_chatBI_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@chatBI_strategy@#$agiledataecho_chatBI_strategy#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@chatBI_gptModel@#$agiledataecho_chatBI_gptModel#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@language@#$agiledataecho_language#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@gmc_uri@#gmc_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml

sed -i "s#@apollo_cluster@#$agiledataecho_apollo_cluster#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@apollo_meta@#$agiledataecho_apollo_meta#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@apollo_namespaces@#$agiledataecho_apollo_namespaces#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@loadbalance_enable@#$agiledataecho_loadbalance_enable#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@nacos_serverAddr@#$agiledataecho_nacos_serverAddr#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml

sed -i "s#@xxl_job_admin_addresses@#$agiledataecho_xxl_job_admin_addresses#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@xxl_job_accessToken@#$agiledataecho_xxl_job_accessToken#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@xxl_job_executor_appname@#$agiledataecho_xxl_job_executor_appname#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@xxl_job_executor_address@#$agiledataecho_xxl_job_executor_address#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@xxl_job_executor_ip@#$agiledataecho_xxl_job_executor_ip#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@xxl_job_executor_port@#$agiledataecho_xxl_job_executor_port#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@xxl_job_executor_logpath@#$agiledataecho_xxl_job_executor_logpath#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@xxl_job_executor_logretentiondays@#$agiledataecho_xxl_job_executor_logretentiondays#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml


sed -i -E 's/\$\{([^:{}]+)(:[^}]*)?\}/\${agiledataecho_\1\2}/g' /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml

cp -r /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/application.yml
cp -r /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/logback-spring-private.xml /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/logback-spring.xml


#这里的脚本 大家自己发挥，前提是 保证classes下的application.yml 或者application.properties 文件中的配置项 替换成自己的配置

==> agiledataecho-0.0.2.0021-sources.jar: replacer.sh <==
#!/bin/sh
sed -i "s#@profile_active@#$agiledataecho_profile_active#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@athena_logger_enable@#$agiledataecho_athena_logger_enable#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
#sed -i "s#@lmc_log_endpoint@#$agiledataecho_lmc_log_endpoint#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/logback-spring.xml

sed -i "s#@redis_host@#$agiledataecho_redis_host#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@redis_port@#$agiledataecho_redis_port#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@redis_password@#$agiledataecho_redis_password#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml

sed -i "s#@mongodb_database@#$agiledataecho_mongodb_echo_database#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@mongodb_echo_agileDataPagebase@#$agiledataecho_mongodb_echo_agileDataPagebase#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml


sed -i "s#@dbServer@#$agiledataecho_dbServer#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@dbName@#$agiledataecho_dbName#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@dbUser@#$agiledataecho_dbUser#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@dbPassword@#$agiledataecho_dbPassword#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml

sed -i "s#@rabbitmq_host@#$agiledataecho_rabbitmq_host#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@rabbitmq_port@#$agiledataecho_rabbitmq_port#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml

sed -i "s#@rabbitmq_username@#$agiledataecho_rabbitmq_username#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@rabbitmq_password@#$agiledataecho_rabbitmq_password#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@rabbitmq_virtual_host@#$agiledataecho_rabbitmq_virtual_host#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml

sed -i "s#@iam_uri@#$agiledataecho_iam_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@iam_bossUri@#$agiledataecho_iam_bossUri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@iam_cacUri@#$agiledataecho_iam_cacUri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@themeMap_uri@#$agiledataecho_themeMap_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@themeMap_rootUri@#$agiledataecho_themeMap_rootUri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@themeMap_dataMapUri@#$agiledataecho_themeMap_dataMapUri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@themeMap_knowledgeGraphUri@#$agiledataecho_themeMap_knowledgeGraphUri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@themeMap_supportPerson@#$agiledataecho_themeMap_supportPerson#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@bpm_uri@#$agiledataecho_bpm_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@uibot_uri@#$agiledataecho_uibot_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@eoc_uri@#$agiledataecho_eoc_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@im_uri@#$agiledataecho_im_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@taskEngine_uri@#$agiledataecho_taskEngine_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@ptm_uri@#$agiledataecho_ptm_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@abt_uri@#$agiledataecho_abt_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@aim_uri@#$agiledataecho_aim_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@aam_uri@#$agiledataecho_aam_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@ade_uri@#$agiledataecho_ade_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@adt_uri@#$agiledataecho_adt_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@semc_uri@#$agiledataecho_semc_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@chatBI_uri@#$agiledataecho_chatBI_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@chatBI_strategy@#$agiledataecho_chatBI_strategy#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@chatBI_gptModel@#$agiledataecho_chatBI_gptModel#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@language@#$agiledataecho_language#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@gmc_uri@#gmc_uri#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml

sed -i "s#@apollo_cluster@#$agiledataecho_apollo_cluster#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@apollo_meta@#$agiledataecho_apollo_meta#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@apollo_namespaces@#$agiledataecho_apollo_namespaces#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@loadbalance_enable@#$agiledataecho_loadbalance_enable#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@nacos_serverAddr@#$agiledataecho_nacos_serverAddr#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml

sed -i "s#@xxl_job_admin_addresses@#$agiledataecho_xxl_job_admin_addresses#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@xxl_job_accessToken@#$agiledataecho_xxl_job_accessToken#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@xxl_job_executor_appname@#$agiledataecho_xxl_job_executor_appname#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@xxl_job_executor_address@#$agiledataecho_xxl_job_executor_address#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@xxl_job_executor_ip@#$agiledataecho_xxl_job_executor_ip#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@xxl_job_executor_port@#$agiledataecho_xxl_job_executor_port#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@xxl_job_executor_logpath@#$agiledataecho_xxl_job_executor_logpath#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml
sed -i "s#@xxl_job_executor_logretentiondays@#$agiledataecho_xxl_job_executor_logretentiondays#g" /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml


sed -i -E 's/\$\{([^:{}]+)(:[^}]*)?\}/\${agiledataecho_\1\2}/g' /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml

cp -r /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/application.yml /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/application.yml
cp -r /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/docker/logback-spring-private.xml /usr/local/tomcat/webapps/agiledataecho/WEB-INF/classes/logback-spring.xml


#这里的脚本 大家自己发挥，前提是 保证classes下的application.yml 或者application.properties 文件中的配置项 替换成自己的配置
